nodeenv: A tool to create isolated node.js environments
=======================================================

Description
-----------

nodeenv (node.js virtual environment) is a tool to create isolated node.js environments.

It creates an environment that has its own installation directories, that doesn’t share
libraries with other node.js virtual environments.

License
-------

BSD License

Upstream Contact
----------------

Home page: https://github.com/ekalinin/nodeenv

Dependencies
------------

- Python
